Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(176)

Unified Diff: base/win/process_startup_helper.cc

Issue 1387963006: Adding error handlers to setup.exe (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Fix lint errors/warnings Created 5 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « base/win/process_startup_helper.h ('k') | chrome/BUILD.gn » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: base/win/process_startup_helper.cc
diff --git a/content/app/startup_helper_win.cc b/base/win/process_startup_helper.cc
similarity index 57%
rename from content/app/startup_helper_win.cc
rename to base/win/process_startup_helper.cc
index 187a0f0870204051f93e829092ef120d58ce4000..b7a81fd303fdc924829f496cfdabd8f29ad3d344 100644
--- a/content/app/startup_helper_win.cc
+++ b/base/win/process_startup_helper.cc
@@ -1,69 +1,55 @@
-// Copyright (c) 2011 The Chromium Authors. All rights reserved.
-// Use of this source code is governed by a BSD-style license that can be
-// found in the LICENSE file.
-
-#include "content/public/app/startup_helper_win.h"
-
-#include <crtdbg.h>
-#include <new.h>
-
-#include "base/base_switches.h"
-#include "base/command_line.h"
-#include "base/win/windows_version.h"
-#include "sandbox/win/src/process_mitigations.h"
-#include "sandbox/win/src/sandbox_factory.h"
-
-namespace {
-
-#pragma optimize("", off)
-// Handlers for invalid parameter and pure call. They generate a breakpoint to
-// tell breakpad that it needs to dump the process.
-void InvalidParameter(const wchar_t* expression, const wchar_t* function,
- const wchar_t* file, unsigned int line,
- uintptr_t reserved) {
- __debugbreak();
- _exit(1);
-}
-
-void PureCall() {
- __debugbreak();
- _exit(1);
-}
-#pragma optimize("", on)
-
-} // namespace
-
-namespace content {
-
-void InitializeSandboxInfo(sandbox::SandboxInterfaceInfo* info) {
- info->broker_services = sandbox::SandboxFactory::GetBrokerServices();
- if (!info->broker_services) {
- info->target_services = sandbox::SandboxFactory::GetTargetServices();
- } else {
- // Ensure the proper mitigations are enforced for the browser process.
- sandbox::ApplyProcessMitigationsToCurrentProcess(
- sandbox::MITIGATION_DEP |
- sandbox::MITIGATION_DEP_NO_ATL_THUNK |
- sandbox::MITIGATION_HARDEN_TOKEN_IL_POLICY);
- }
-}
-
-// Register the invalid param handler and pure call handler to be able to
-// notify breakpad when it happens.
-void RegisterInvalidParamHandler() {
- _set_invalid_parameter_handler(InvalidParameter);
- _set_purecall_handler(PureCall);
-}
-
-void SetupCRT(const base::CommandLine& command_line) {
-#if defined(_CRTDBG_MAP_ALLOC)
- _CrtSetReportFile(_CRT_WARN, _CRTDBG_FILE_STDERR);
- _CrtSetReportMode(_CRT_WARN, _CRTDBG_MODE_FILE);
-#else
- if (!command_line.HasSwitch(switches::kDisableBreakpad)) {
- _CrtSetReportMode(_CRT_ASSERT, 0);
- }
-#endif
-}
-
-} // namespace content
+// Copyright (c) 2015 The Chromium Authors. All rights reserved.
+// Use of this source code is governed by a BSD-style license that can be
+// found in the LICENSE file.
+
+#include "base/win/process_startup_helper.h"
+
+#include <crtdbg.h>
+#include <new.h>
+
+#include "base/base_switches.h"
+#include "base/command_line.h"
+
+namespace {
+
+#pragma optimize("", off)
+// Handlers for invalid parameter and pure call. They generate a breakpoint to
+// tell breakpad that it needs to dump the process.
+void InvalidParameter(const wchar_t* expression, const wchar_t* function,
+ const wchar_t* file, unsigned int line,
+ uintptr_t reserved) {
+ __debugbreak();
+ _exit(1);
+}
+
+void PureCall() {
+ __debugbreak();
+ _exit(1);
+}
+#pragma optimize("", on)
+
+} // namespace
+
+namespace base {
+namespace win {
+
+// Register the invalid param handler and pure call handler to be able to
+// notify breakpad when it happens.
+void RegisterInvalidParamHandler() {
+ _set_invalid_parameter_handler(InvalidParameter);
+ _set_purecall_handler(PureCall);
+}
+
+void SetupCRT(const CommandLine& command_line) {
+#if defined(_CRTDBG_MAP_ALLOC)
+ _CrtSetReportFile(_CRT_WARN, _CRTDBG_FILE_STDERR);
+ _CrtSetReportMode(_CRT_WARN, _CRTDBG_MODE_FILE);
+#else
+ if (!command_line.HasSwitch(switches::kDisableBreakpad)) {
+ _CrtSetReportMode(_CRT_ASSERT, 0);
+ }
+#endif
+}
+
+} // namespace win
+} // namespace base
« no previous file with comments | « base/win/process_startup_helper.h ('k') | chrome/BUILD.gn » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698